@@ -1,9 +1,11 @@
 package Net::Appliance::Session;
 {
-  $Net::Appliance::Session::VERSION = '3.122530';
+  $Net::Appliance::Session::VERSION = '4.122630';
 }
 
-use Moose;
+use Moo;
+use Sub::Quote;
+use MooX::Types::MooseLike::Base qw(Bool Str HashRef InstanceOf);
 use Net::CLI::Interact;
 
 with 'Net::Appliance::Session::Transport';
@@ -19,9 +21,9 @@ foreach my $slot (qw/
 /) {
     has $slot => (
         is => 'rw',
-        isa => 'Bool',
+        isa => Bool,
         required => 0,
-        default => 0,
+        default => quote_sub('0'),
     );
 }
 
@@ -34,9 +36,9 @@ foreach my $slot (qw/
 /) {
     has $slot => (
         is => 'rw',
-        isa => 'Bool',
+        isa => Bool,
         required => 0,
-        default => 1,
+        default => quote_sub('1'),
     );
 }
 
@@ -47,11 +49,11 @@ foreach my $slot (qw/
 /) {
     has $slot => (
         is => 'rw',
-        isa => 'Str',
+        isa => Str,
         required => 0,
+        predicate => 1,
         reader => "get_$slot",
         writer => "set_$slot",
-        predicate => "has_$slot",
     );
 }
 
@@ -61,7 +63,7 @@ foreach my $slot (qw/
 /) {
     has $slot => (
         is => 'rw',
-        isa => 'Str',
+        isa => Str,
         required => 1,
     );
 }
@@ -73,23 +75,25 @@ foreach my $slot (qw/
 /) {
     has $slot => (
         is => 'ro',
-        isa => 'Str',
+        isa => Str,
         required => 0,
-        predicate => "has_$slot",
+        predicate => 1,
     );
 }
 
 has 'connect_options' => (
     is => 'ro',
-    isa => 'HashRef',
+    isa => HashRef,
     required => 0,
     default => sub { {} },
 );
 
 has 'nci' => (
-    is => 'ro',
-    isa => 'Net::CLI::Interact',
-    lazy_build => 1,
+    is => 'lazy',
+    isa => InstanceOf['Net::CLI::Interact'],
+    required => 1,
+    predicate => 1,
+    clearer => 1,
     handles => [qw/
         cmd
         macro
@@ -134,14 +138,7 @@ Net::Appliance::Session - Run command-line sessions to network appliances
 
 =head1 VERSION
 
-version 3.122530
-
-=head1 IMPORTANT NOTE ABOUT UPGRADING FROM VERSION 2.x
-
-Between version 2.x and 3.x of this module the programmer's interface changed
-in a number of ways. If you have existing code to migrate to this new version,
-please see the L<Upgrading|Net::Appliance::Session::APIv2>
-document which details all steps necessary.
+version 4.122630
 
 =head1 SYNOPSIS
 
